import { Icon } from '@iconify/react/dist/iconify.js';
import { useAtom } from 'jotai';
import { FC, useCallback } from 'react';
import { useNavigate } from 'react-router-dom';
import EditableContent from '../../components/EditableContent';
import { CurrentPatternAtom } from '../../context/Patterns';
import styles from './PatternHeader.module.css';

const PatternHeader: FC = () => {
  const navigate = useNavigate();
  const [currentPattern, setPattern] = useAtom(CurrentPatternAtom);
  const handleClosePattern = useCallback(() => {
    setPattern(null);
    navigate('/library');
  }, [currentPattern]);

  return (
    <div className={styles.pattern_header}>
      <EditableContent
        as="h3"
        placeholder="Pattern Name"
        value={currentPattern?.name ?? null}
        additionalClassName={styles.content}
      />
      <div className="spacer" />
      <button className="tonal" onClick={handleClosePattern}>
        <Icon icon="material-symbols-light:close" />
        Close Edit
      </button>
    </div>
  );
};

export default PatternHeader;
